@@ -31,6 +31,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import os
+from threading import Lock
 from xml.etree.cElementTree import ElementTree
 
 from .common import MANIFEST_FILE, PACKAGE_FILE, STACK_FILE, ResourceNotFound
@@ -38,6 +39,9 @@ from .environment import get_ros_paths
 from .manifest import parse_manifest_file, InvalidManifest
 from .stack import parse_stack_file, InvalidStack
 
+_cache_lock = Lock()
+
+
 def list_by_path(manifest_name, path, cache):
     """
     List ROS stacks or packages within the specified path.
@@ -159,16 +163,21 @@ class ManifestManager(object):
             return self._load_manifest(name)
             
     def _update_location_cache(self):
-        if self._location_cache is not None:
-            return
-        # initialize cache
-        cache = self._location_cache = {}
-        # nothing to search, #3680
-        if not self._ros_paths:
-            return
-        # crawl paths using our own logic, in reverse order to get correct precedence
-        for path in reversed(self._ros_paths):
-            list_by_path(self._manifest_name, path, cache)
+        global _cache_lock
+        # ensure self._location_cache is not checked while it is being updated
+        # (i.e. while it is not None, but also not completely populated)
+        with _cache_lock:
+            if self._location_cache is not None:
+                return
+            # initialize cache
+            cache = self._location_cache = {}
+            # nothing to search, #3680
+            if not self._ros_paths:
+                return
+            # crawl paths using our own logic, in reverse order to get
+            # correct precedence
+            for path in reversed(self._ros_paths):
+                list_by_path(self._manifest_name, path, cache)
     
     def list(self):
         """
